# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

This changelog is auto-generated by [release-please](https://github.com/googleapis/release-please).

## [1.11.2](https://github.com/tofupilot/python-client/compare/v1.11.0...v1.11.2) (2025-05-16)


### Bug Fixes

* "open api call" in the operator UI sometimes leading to the wrong call ([06c8974](https://github.com/tofupilot/python-client/commit/06c897420fe1fc53fbc4a0a20b23e4679518f211))
* client disconnecting after around 1h ([56fb808](https://github.com/tofupilot/python-client/commit/56fb808e5a0b61088a74384da7256fd3fb615637))
* incorrect instruction on how to disable streaming on streaming fail ([5e018a4](https://github.com/tofupilot/python-client/commit/5e018a4eeb55f7680fe5eabbd7944674a64c4674))
* issue uploading attachments ([cfc2a26](https://github.com/tofupilot/python-client/commit/cfc2a26b623fa45d0e3191adfc43b314727e6181))
* operator UI disconnectig permanently when internet connection lost ([f4f57f4](https://github.com/tofupilot/python-client/commit/f4f57f4b469d02b9301f656589af9667823be3b6))
* use of feature unsupported in python 3.9 ([cfc2a26](https://github.com/tofupilot/python-client/commit/cfc2a26b623fa45d0e3191adfc43b314727e6181))


### Miscellaneous Chores

* release 1.11.2 ([ea50c6d](https://github.com/tofupilot/python-client/commit/ea50c6d2f1d5a1c2f7619a0fecfed470e07e157e))

## [1.9.4](https://github.com/tofupilot/python-client/compare/v1.9.3...v1.9.4) (2025-02-24)


### Bug Fixes

* client.create_run_from_openhtf_report was not uploading attachments ([ff59296](https://github.com/tofupilot/python-client/commit/ff59296deda23acc82f835cc58a1cd756dcae824))

## [1.9.3](https://github.com/tofupilot/python-client/compare/v1.9.2...v1.9.3) (2025-01-31)


### Bug Fixes

* automatic testing script was not rendering special characters from terminal outputs on Windows ([8d79c12](https://github.com/tofupilot/python-client/commit/8d79c123ebc1ea21e5bb3df919300928b1597bd6))
* typo in docstring of client's method ([dce6860](https://github.com/tofupilot/python-client/commit/dce68603c719c9a5374daf4f03e953c9a46569a5))

## [1.9.2](https://github.com/tofupilot/python-client/compare/v1.9.1...v1.9.2) (2025-01-28)


### Bug Fixes

* made temporary file creation for openhtf OS-agnostic ([68f9ec5](https://github.com/tofupilot/python-client/commit/68f9ec586f9fedb6cc285088c73b911efb2fd670))

## [1.9.1](https://github.com/tofupilot/python-client/compare/v1.9.0...v1.9.1) (2025-01-28)


### Bug Fixes

* Made OpenHTF integration work in read-only environments ([00fd0d3](https://github.com/tofupilot/python-client/commit/00fd0d33edbcf70d440bd3d81ce0deffd9bc15c5))

## [1.9.0](https://github.com/tofupilot/python-client/compare/v1.8.0...v1.9.0) (2024-12-20)


### Features

* Enum to handle Measurements outcome and Phases outcome ([60879a5](https://github.com/tofupilot/python-client/commit/60879a584b09d3f5af6f243b1204a9e38bc8acd2))
* new phases property in client.create_run method ([46b335d](https://github.com/tofupilot/python-client/commit/46b335dd3c32fc4ac1edc0b319584c4d08f890d6))

## [1.8.0](https://github.com/tofupilot/python-client/compare/v1.7.0...v1.8.0) (2024-12-06)


### Features

* handling of new property in create_run method ([f99a46e](https://github.com/tofupilot/python-client/commit/f99a46e157c16dec2fd091db6f007bd1ce91de56))
* new method to delete unit ([a05a6d2](https://github.com/tofupilot/python-client/commit/a05a6d24180aa757c472d7bd518dc346301e17c3))
* run deletion route ([bbd1761](https://github.com/tofupilot/python-client/commit/bbd17618dfe935f3cafad2e7de15fe9ca32f030f))

## [1.7.0](https://github.com/tofupilot/python-client/compare/v1.6.0...v1.7.0) (2024-11-29)


### Features

* Robust exception and retries handling ([30ee8b6](https://github.com/tofupilot/python-client/commit/30ee8b63c9e6fe95ad3a913e156a54fe04f4c15a))

## [1.6.0](https://github.com/tofupilot/python-client/compare/v1.5.1...v1.6.0) (2024-11-05)


### Features

* Real time streaming of openhtf test execution through remote websocket server ([bf21c64](https://github.com/tofupilot/python-client/commit/bf21c64e438f3ec7cc90119128152f4556a4b554))

## [1.5.1](https://github.com/tofupilot/python-client/compare/v1.5.0...v1.5.1) (2024-10-18)


### Bug Fixes

* removed unnecessary dependencies ([7fce595](https://github.com/tofupilot/python-client/commit/7fce59502b285f03032851838af531104e39118b))

## [1.5.0](https://github.com/tofupilot/python-client/compare/v1.4.0...v1.5.0) (2024-10-18)


### Features

* new TofuPilot context manager ([f9a159e](https://github.com/tofupilot/python-client/commit/f9a159e0a869996f030cd83e6eae78d8fd19c191))


### Bug Fixes

* option to allow nan did not work for upload callback ([747a4b3](https://github.com/tofupilot/python-client/commit/747a4b386bd09bf432a362abd8e7826acee688ee))

## [1.4.0](https://github.com/tofupilot/python-client/compare/v1.3.0...v1.4.0) (2024-10-11)


### Features

* new UploadToTofuPilot class to help importing OpenHTF script to TofuPilot ([be0733e](https://github.com/tofupilot/python-client/commit/be0733e6ed9436133c2ccdc77b894d487a182b00))
* support of attachments in UploadToTofuPilot class ([d44f26f](https://github.com/tofupilot/python-client/commit/d44f26f0901558a4cf4732308f857a049f4a95ef))

## [1.3.0](https://github.com/tofupilot/python-client/compare/v1.2.1...v1.3.0) (2024-10-07)


### Features

* added attachments to pytest framework ([41d846c](https://github.com/tofupilot/python-client/commit/41d846ce11fdde315b3d4344e71a6789e794c18c))
* added create_run_from_file method ([ae413de](https://github.com/tofupilot/python-client/commit/ae413de448d2f0085798488cf28f50db42b2bacc))
* Added get_unit method to client to retrieve runs ([c9a369f](https://github.com/tofupilot/python-client/commit/c9a369fdb83ab8bedda0690d372bb58e37dc8e20))
* Added report variables to pytest framework ([2ca625f](https://github.com/tofupilot/python-client/commit/2ca625fe22586bab3b221e511507fb7e435fe709))
* added sub-units to pytest framework ([0958825](https://github.com/tofupilot/python-client/commit/09588258c7ebbcf0e3b3e3fbce817a394e3113af))
* Added update_unit method to client ([0124631](https://github.com/tofupilot/python-client/commit/012463197d37d002540bd20ddde4ca22a322e2ac))

## [1.2.1](https://github.com/tofupilot/python-client/compare/v1.2.0...v1.2.1) (2024-08-28)

### Bug Fixes

- remove double warning ([647717d](https://github.com/tofupilot/python-client/commit/647717d4413db0eedbd995a7339bebefb8c1ccfe))

## [1.2.0] - 2024-08-23

### Added

- Centralized all constant values in a dedicated `/constants` folder
- Introduced sending of metadata containing package type and version when communicating with TofuPilot API
- Implemented logging of any warning received from API

### Fixed

- Corrected an issue where an exception was risen before user was informed that their API key was incorrect

### Changed

- Enhanced the logging and error messages related to attachments and run creation
- Updated the success message handling to now be received directly from the API, rather than being computed by the client
- Reorganized the README.md by swapping the Documentation and Examples sections
- Updated links in README.md from relative to absolute, ensuring they work correctly across all contexts where the documentation is viewed

### Removed

- `raw_response` property in responses sent by client
- Checking of file format during attachment upload (to keep only size checking)

## [1.1.1] - 2024-07-22

### Fixed

- `steps` parameter was required in client.create_run method

## [1.1.0] - 2024-07-19

### Added

- `steps` parameter in client.create_run method to reflect TofuPilot's API update

## [1.0.0] - 2024-07-16

### Added

- LICENSE.md file
- CONTRIBUTING.md file
- CODE_OF_CONDUCT.md file
- Unitary tests in new tests/ folder
- Functional tests in new examples/ folder
- Docstring for the client’s create_run method
- Github action for automatic testing
- Github action for automatic release in Pypi

### Fixed

- Replaced deprecated package pkg_resources with a maintained alternative

### Changed

- Open-sourced the repository
- Made API key readable from environment
- Detailed the project in README.md
- Standardized and enhanced logging output for better readability

## [0.1.20] - 2024-06-28

### Changed

- renamed "params" to "report_variables"

## [0.1.19] - 2024-06-28

### Changed

- Made the “duration” parameter of the client optional to match the API
- Made the client.create_run method return an object containing only the run URL, not its ID

## [0.1.18] - 2024-06-28

### Added

- Option to add different base URL to the client

## [0.1.17] - 2024-06-28

### Fixed

- Removed example client code

## [0.1.16] - 2024-06-28

### Added

- Handling of file attachments

### Changed

- Removed the "test_function" parameter and replaced it with an API wrapper

## [0.1.15] - 2024-06-26

### Changed

- Moved "params" parameter of the client to the optional return value of "test_function"

## [0.1.14] - 2024-06-20

### Fixed

- Fixed client call to use localhost instead of the TP website

## [0.1.13] - 2024-06-20

### Changed

- Updated the signature of the client’s create_run method to match the new TofuPilot API format

## [0.1.12] - 2024-06-17

### Added

- Logging of all calls to stdout or stderr in test_function

## [0.1.11] - 2024-06-13

### Added

- "raw_response" parameter to the create_run method

### Changed

- Error messages are now formatted as: { "error": error_msg }

## [0.1.10] - 2024-06-13

### Changed

- Return type of the create_run method

## [0.1.9] - 2024-06-10

### Fixed

- Imports

## [0.1.8] - 2024-06-10

### Added

- Missing requirements

## [0.1.7] - 2024-06-10

### Added

- Print and logging of the run URL before returning it
- Package version check
- Hid all attributes of TofuPilotClient except the create_run method

## [0.1.6] - 2024-06-10

### Changed

- Removed base_url parameter from TofuPilotClient constructor
- Renamed method create_test_run to create_run
- Made "component_revision" parameter of method create_run optional to match TofuPilot API

## [0.1.5] - 2024-06-10

### Changed

- Improved error messages
- Added custom exception class (TofuPilotClientError)
- Logging of errors

## [0.1.4] - 2024-06-07

### Added

- MANIFEST.in file

## [0.1.3] - 2024-06-07

### Added

- CHANGELOG.md file

### Changed

- Transferred repository to the tofupilot organization
